@@ -23,7 +23,7 @@ import sys, os
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinxcontrib.adadomain']
+extensions = []
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
@@ -36,15 +36,15 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'Ahven'
-copyright = '2011, Tero Koskinen'
+copyright = '2018, Tero Koskinen'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '2.1'
+version = '2.7'
 # The full version, including alpha/beta/rc tags.
-release = '2.1'
+release = '2.7'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
@@ -168,6 +168,8 @@ latex_documents = [
    'Tero Koskinen', 'manual'),
 ]
 
+highlight_language = 'ada'
+
 # The name of an image file (relative to this directory) to place at the top of
 # the title page.
 #latex_logo = None
